.. _installation:

Installation
============

**Python 3.5 or greater** is required. This package may also work for
Python 2.7 or greater, however we do not provide any guarantee neither we will
make any effort to maintain back compatibility with Python 2.

From PyPI
~~~~~~~~~
To install ``spgl1`` within your current environment, simply type:

.. code-block:: bash

   >> pip install spgl1

From source
~~~~~~~~~~~

First of all clone the repository. To install ``spgl1`` within your current
environment, simply type:

.. code-block:: bash

   >> make install

or as a developer:

.. code-block:: bash

   >> make dev-install

To install ``spgl1`` in a new conda environment, type:

.. code-block:: bash

   >> make install_conda

or as a developer:

.. code-block:: bash

   >> make dev-install_conda